<?php

namespace App\paypay;

use tgMdk\dto\PayPayCaptureRequestDto;
use tgMdk\TGMDK_Transaction;

/*
 * PayPayオンライン決済(売上)サンプル
 * Created on 2020/07/09
 *
 */

/**
 * ステータスコード
 */
define('TXN_FAILURE_CODE', 'failure');
define('TXN_PENDING_CODE', 'pending');
define('TXN_SUCCESS_CODE', 'success');

require_once("../../vendor/autoload.php");
require_once("../LoggerDefine.php");

/**
 * 取引ID
 * 決済申込時に利用したものを設定してください
 */
$order_id = "";

/**
 * サービスオプションタイプ
 */
$service_option_type = "online";

/**
 * 売上金額
 * 未指定の場合は全額売上となります。
 */
$amount = "";

/**
 * 注文の説明
 */
$order_description = "注文の説明";

/**
 * 要求電文パラメータ値の指定
 */
$request_data = new PayPayCaptureRequestDto();

$request_data->setOrderId($order_id);
$request_data->setServiceOptionType($service_option_type);
$request_data->setAmount($amount);
$request_data->setOrderDescription($order_description);

/**
 * 実施
 */
$transaction = new TGMDK_Transaction();
$response_data = $transaction->execute($request_data);

/**
 * 結果コード取得
 */
$txn_status = $response_data->getMStatus();
/**
 * 詳細コード取得
 */
$txn_result_code = $response_data->getVResultCode();
/**
 * エラーメッセージ取得
 */
$error_message = $response_data->getMerrMsg();

/**
 * 結果表示
 */
// 成功
if (TXN_SUCCESS_CODE === $txn_status) {
    echo $txn_status . "\n";
    echo "Transaction Successfully Complete\n";
    echo "[Result Code]: " . $txn_result_code . "\n";
    echo "[Order ID]: " . $response_data->getOrderId() . "\n";
    echo "[Balance]: " . $response_data->getBalance() . "\n";
    //ペンディング
} else if (TXN_PENDING_CODE === $txn_status) {
    echo $txn_status . "\n";
    echo "Transaction Pending\n";
    echo "[Message]: " . $error_message . "\n";
    echo "[Result Code]: " . $txn_result_code . "\n";
    echo "[Order ID]: " . $response_data->getOrderId() . "\n";
    echo "Check log file for more information\n";
    // 失敗
} else if (TXN_FAILURE_CODE === $txn_status) {
    echo $txn_status . "\n";
    echo "Transaction Failure\n";
    echo "[Message]: " . $error_message . "\n";
    echo "[Result Code]: " . $txn_result_code . "\n";
    echo "[Order ID]: " . $response_data->getOrderId() . "\n";
    echo "Check log file for more information\n";
}
